<?php
/**
* @copyright   (C) 2011 iJoomla, Inc. - All rights reserved.
* @license  GNU General Public License, version 2 (http://www.gnu.org/licenses/gpl-2.0.html) 
* @author  iJoomla.com webmaster@ijoomla.com
* @url   http://www.ijoomla.com/licensing/
* the PHP code portions are distributed under the GPL license. If not otherwise stated, all images, manuals, cascading style sheets, and included JavaScript  
* are NOT GPL, and are released under the IJOOMLA Proprietary Use License v1.0 
* More info at http://www.ijoomla.com/licensing/
*/
// No direct access to this file
defined('_JEXEC') or die('Restricted access');
jimport('joomla.application.component.modellist');

class MediapassModelCategories extends JModelList{
	
	public function __construct($config = array()){
		if(empty($config['filter_fields'])){
			$config['filter_fields'] = array(
				'title', 'a.title',				
				'lft', 'a.lft'				
			);
		}
		parent::__construct($config);
	}
	
	protected function populateState($ordering = null, $direction = null){
		// Initialise variables.
		$app		= JFactory::getApplication();
		$context	= $this->context;
		// List state information.
		parent::populateState('a.lft', 'asc');
	}
	
	function getListQuery(){
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);
		$user	= JFactory::getUser();

		$query->select(
			$this->getState(
				'list.select',
				'a.id, a.title, a.alias, a.note, a.published, a.access' .
				', a.checked_out, a.checked_out_time, a.created_user_id' .
				', a.path, a.parent_id, a.level, a.lft, a.rgt' .
				', a.language'
			)
		);
		$query->from('#__categories AS a');

		// Join over the language
		$query->select('l.title AS language_title');
		$query->join('LEFT', '`#__languages` AS l ON l.lang_code = a.language');

		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');

		// Join over the asset groups.
		$query->select('ag.title AS access_level');
		$query->join('LEFT', '#__viewlevels AS ag ON ag.id = a.access');

		// Join over the users for the author.
		$query->select('ua.name AS author_name');
		$query->join('LEFT', '#__users AS ua ON ua.id = a.created_user_id');

		// Filter by extension
		//if ($extension = $this->getState('filter.extension')) {
			$query->where("a.extension = 'com_content'");
		//}

		// Filter on the level.
		if ($level = $this->getState('filter.level')) {
			$query->where('a.level <= '.(int) $level);
		}

		// Filter by access level.
		if ($access = $this->getState('filter.access')) {
			$query->where('a.access = ' . (int) $access);
		}

		// Implement View Level Access
		if (!$user->authorise('core.admin'))
		{
		    $groups	= implode(',', $user->getAuthorisedViewLevels());
			$query->where('a.access IN ('.$groups.')');
		}

		// Filter by published state
		/*$published = $this->getState('filter.published');
		if (is_numeric($published)) {
			$query->where('a.published = ' . (int) $published);
		}
		else if ($published === '') {*/
			$query->where('(a.published IN (0, 1))');
		//}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			}
			else if (stripos($search, 'author:') === 0) {
				$search = $db->Quote('%'.$db->getEscaped(substr($search, 7), true).'%');
				$query->where('(ua.name LIKE '.$search.' OR ua.username LIKE '.$search.')');
			}
			else {
				$search = $db->Quote('%'.$db->getEscaped($search, true).'%');
				$query->where('(a.title LIKE '.$search.' OR a.alias LIKE '.$search.' OR a.note LIKE '.$search.')');
			}
		}

		// Filter on the language.
		if ($language = $this->getState('filter.language')) {
			$query->where('a.language = '.$db->quote($language));
		}

		// Add the list ordering clause.
		$query->order($db->getEscaped($this->getState('list.ordering', 'a.title')).' '.$db->getEscaped($this->getState('list.direction', 'ASC')));		
		return $query;
	}
	
	function getMediapassCategories(){
		$db =& JFactory::getDBO();
		$sql = "select id, category_id from #__mediapass_categories";
		$db->setQuery($sql);
		$db->query();
		$result = $db->loadAssocList("category_id");
		return $result;
	}
	
	function store(){
		$db =& JFactory::getDBO();
		$sql = "select category_id from #__mediapass_categories";
		$db->setQuery($sql);
		$db->query();
		$from_database = $db->loadAssocList();
		if(isset($from_database)){
			$temp = array();
			foreach($from_database as $key=>$value){
				$temp[] = $value["category_id"];
			}
			$from_database = $temp;
		}
		else{
			$from_database = array();
		}
		
		$checked = JRequest::getVar("cid", array(), "post", "array");
		$all_ids_per_page = JRequest::getVar("all_ids", "");
		$all_ids_per_page = explode(",", $all_ids_per_page);
		$for_delete = array_diff($all_ids_per_page, $checked);
		$for_save = array_diff($checked, $from_database);
		
		if(count($for_delete) == 0){
			$for_delete[] = 0;
		}
		
		$sql = "delete from #__mediapass_categories where category_id in (".implode(",", $for_delete).")";
		$db->setQuery($sql);
		if($db->query()){
			if(isset($for_save) && count($for_save) > 0){
				foreach($for_save as $key=>$value){
					$sql = "insert into #__mediapass_categories(`category_id`) values (".$value.")";					
					$db->setQuery($sql);
					if(!$db->query()){
						return false;
					}
				}
			}
		}
		else{
			return false;
		}
		return true;
	}
}

?>

